import{_ as e,n as l,s,x as a}from"./index-CZy-fyXs.js";import"./c.wXqWYNVx.js";import"./c.0EIqk-ip.js";let o=class extends s{render(){return a`
      <esphome-process-dialog
        heading="Clean All Files"
        .type=${"clean-all"}
        .spawnParams=${{clean_build_dir:!0}}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};o=e([l("esphome-clean-all-dialog")],o);
//# sourceMappingURL=c.Zz9yQpRd.js.map
