import{_ as e,e as o,n as i,s,x as t}from"./index-CZy-fyXs.js";import"./c.wXqWYNVx.js";import"./c.0EIqk-ip.js";let n=class extends s{render(){return t`
      <esphome-process-dialog
        .heading=${`Clean MQTT discovery topics for ${this.configuration}`}
        .type=${"clean-mqtt"}
        .spawnParams=${{configuration:this.configuration}}
        @closed=${this._handleClose}
      >
      </esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};e([o()],n.prototype,"configuration",void 0),n=e([i("esphome-clean-mqtt-dialog")],n);
//# sourceMappingURL=c.BirT7ZBZ.js.map
